@@ -19,3 +19,8 @@
 # Field types
 A_FIELD = 0
 B_FIELD = 1
+
+FIELD_TYPES_STR = {
+    A_FIELD: "A_FIELD",
+    B_FIELD: "B_FIELD"
+}
